package com.nokia.hb.config.web;

import lombok.NoArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

/**
 * 登录拦截器
 */
@Slf4j
@NoArgsConstructor
public class LoginHandlerInterceptor implements HandlerInterceptor {
    /**
     * session过期时间（秒）
     */
    private Integer timeoutSeconds;

    public LoginHandlerInterceptor(Integer timeoutSeconds) {
        this.timeoutSeconds = timeoutSeconds;
    }

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        HttpSession session = request.getSession();
        Object username = session.getAttribute("username");
        log.debug("username: {}", username);
        // 用户名为空重定向登录页面
        if (username == null) {
            response.sendRedirect("/login");
            return false;
        }
        // 延长session过期时间
        session.setMaxInactiveInterval(timeoutSeconds);
        return true;
    }
}
