package com.nokia.hb.config.web;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.web.servlet.DispatcherServletAutoConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.DispatcherServlet;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

@Configuration
public class MyWebMvcConfigurer implements WebMvcConfigurer {
    /**
     * session过期时间（秒）
     */
    @Value("${session.timeout}")
    private Integer timeoutSeconds;

    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        // 添加请求日志拦截
        registry.addInterceptor(new RequestLogHandlerInterceptor())
                .addPathPatterns("/**")
                .excludePathPatterns("/", "/login", "/template", "/error", "/js/**", "/html/**", "/image/**", "/css/**");
        // 添加登录拦截
        registry.addInterceptor(new LoginHandlerInterceptor(timeoutSeconds))
                .addPathPatterns("/**")
                .excludePathPatterns("/login", "/error", "/userLogin", "/js/**", "/html/**", "/image/**", "/css/**");
    }

    /**
     * 使用自定义DispatcherServlet
     */
    @Bean
    @Qualifier(DispatcherServletAutoConfiguration.DEFAULT_DISPATCHER_SERVLET_BEAN_NAME)
    public DispatcherServlet dispatcherServlet() {
        return new MyDispatcherServlet();
    }
}
