package com.nokia.hb.controller;

import com.nokia.hb.pojo.RetData;
import com.nokia.hb.pojo.TreeNode;
import com.nokia.hb.utils.DbUtil;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpSession;
import java.util.List;

@RestController
public class TemplateController {
    /**
     * 用户登录
     */
    @PostMapping("userLogin")
    public Object userLogin(String username, String password, HttpSession session) {
        return DbUtil.userLogin(username, password, session);
    }

    /**
     * 查询地市树形结构
     *
     * @return {@link List}<{@link TreeNode}>
     */
    @GetMapping("initTreeCitys")
    public List<TreeNode> initTreeCitys() {
        return DbUtil.initTreeCitys();
    }

    /**
     * 查询指标树形结构
     *
     * @return {@link List}<{@link TreeNode}>
     */
    @GetMapping("initTreeIndicator")
    public List<TreeNode> initTreeIndicator() {
        return DbUtil.initTreeIndicator();
    }

    /**
     * 查询pm数据
     *
     * @param citys      地市
     * @param quxians    区县
     * @param indicators 指标
     * @param ttype      时间单位
     * @param sdate      时间范围
     * @param condition  条件
     * @param searchType 搜索类型
     * @param session    会话
     * @return {@link RetData}
     */
    @PostMapping("renderTable")
    public RetData renderTable(String citys, String quxians, String indicators, String ttype, String sdate,
                               String condition, String searchType, HttpSession session) {
        return DbUtil.renderTable(citys, quxians, indicators, ttype, sdate, condition, searchType, session);
    }

    /**
     * 添加指标模板
     *
     * @param templateName 指标模板名称
     * @param indicators   指标
     */
    @PostMapping("addTemplate")
    public Object addTemplate(String templateName, String indicators, HttpSession session) {
        return DbUtil.addTemplate(templateName, indicators, session);
    }

    /**
     * 获取指标模板
     */
    @GetMapping("initTreeIndicatorTemplate")
    public List<TreeNode> initTreeIndicatorTemplate(HttpSession session) {
        return DbUtil.initTreeIndicatorTemplate(session);
    }

    /**
     * 删除指标模板
     *
     * @param ids 模板id
     */
    @PostMapping("deleteTemplate")
    public Object deleteTemplate(String ids) {

        return DbUtil.deleteTemplate(ids);
    }
}
